@@ -23,7 +23,9 @@ def indentation():
     print("You dont have to use the braces, the regular indentation works too")
 
 
-anotherTest()
+if (True){}
+
+indentation()
 
 dict = {"hello":1};
 
